import { DisplayService } from './display'
import { AlarmService } from './api'

export default class DisplayIdleWatcher {

  constructor(displayService: DisplayService, alarmService: AlarmService) {
    this.displayService = displayService
    this.alarmService = alarmService
  }

  private displayService: DisplayService
  private alarmService: AlarmService

  private lastAlarmId: number
  private timerReference: NodeJS.Timer
  public timerInterval = 2000

  public get isWatching(): boolean {
    return this.timerReference === null
  }

  public startWatching(accesskey: string) {
    if (this.timerReference !== null) clearInterval(this.timerReference)

    this.timerReference = setInterval(async () => {
      try {
        const activeAlarm = await this.alarmService.getActiveAlarm(accesskey)

        if (activeAlarm === null && this.lastAlarmId !== null) {
          this.lastAlarmId = null
          this.displayService.turnOff()
          return
        }

        if (activeAlarm !== null && (this.lastAlarmId === null || activeAlarm.id !== this.lastAlarmId)) {
          this.displayService.turnOn()
          this.lastAlarmId = activeAlarm.id
          return
        }
      } catch (error) {
        console.error(error)
      }
    }, this.timerInterval)
  }

  public stopWatching() {
    if (this.timerReference === null) return

    clearInterval(this.timerReference)
    this.timerReference = null
    this.displayService.turnOn()
  }

}
