import { exec, ChildProcess } from 'child_process'
import { release as getOsRelease } from 'os'

import AbstractDisplayService from './AbstractDisplayService'

export default class DisplayServiceLinux extends AbstractDisplayService {

  private childProcess: ChildProcess
  private get screensaverPath() {
    if (getOsRelease().startsWith('17.')) {
      // High Sierra and later
      return '/System/Library/CoreServices/ScreenSaverEngine.app/Contents/MacOS/ScreenSaverEngine'
    } else {
      // Sierra and before
      return '/System/Library/Frameworks/ScreenSaver.framework/Resources/ScreenSaverEngine.app/Contents/MacOS/ScreenSaverEngine'
    }
  }

  _turnOn() {
    if (this.childProcess === undefined || this.childProcess === null) {
      console.log('Display is already on')
      return
    }

    this.childProcess = exec(`kill ${this.childProcess.pid}`)
    this.childProcess.stderr.on('data', (data: string) => {
      console.error(data)
    })
  }

  _turnOff() {
    this.childProcess = exec(this.screensaverPath)
    this.childProcess.stderr.on('data', (data: string) => {
      console.error(data)
    })
  }

}
